@@ -126,6 +126,13 @@ static void mymergesort( int first, int last, Segment **seg )
 	static TLS int i, j, k, p;
 	static TLS int allo = 0;
 	static TLS Segment **work = NULL;
+
+	if( seg == NULL )
+	{
+		free( work ); work = NULL;
+		return;
+	}
+
 	if( last > allo )
 	{
 		allo = last;
@@ -153,12 +160,14 @@ static void mymergesort( int first, int last, Segment **seg )
 }
 
 
-float Falign_localhom( char  **seq1, char  **seq2, 
+float Falign_localhom( 
+			  char  **seq1, char  **seq2, 
 			  double *eff1, double *eff2, 
 			  int    clus1, int    clus2,
 			  int alloclen, 
 			   LocalHom ***localhom, float *totalimpmatch,
-			   int *gapmap1, int *gapmap2 )
+			   int *gapmap1, int *gapmap2,
+				int *chudanpt, int chudanref, int *chudanres )
 {
    // tditeration.c deha alloclen ha huhen nanode
    // prevalloclen ha iranai.
@@ -205,6 +214,56 @@ float Falign_localhom( char  **seq1, char  **seq2,
 	extern Fukusosuu   *AllocateFukusosuuVec();
 	extern Fukusosuu  **AllocateFukusosuuMtx();
 
+	if( seq1 == NULL )
+	{
+		if( result1 ) 
+		{
+//			fprintf( stderr, "Freeing localarrays in Falign\n" );
+			localalloclen = 0;
+			mymergesort( 0, 0, NULL );
+			alignableReagion( 0, 0, NULL, NULL, NULL, NULL, NULL );
+			fft( 0, NULL, 1 );
+			A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			G__align11( NULL, NULL, NULL, 0, 0, 0 );
+			partA__align( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL );
+			blockAlign2( NULL, NULL, NULL, NULL, NULL, NULL );
+			if( crossscore ) FreeDoubleMtx( crossscore );
+			FreeCharMtx( result1 );
+			FreeCharMtx( result2 );
+			FreeCharMtx( tmpres1 );
+			FreeCharMtx( tmpres2 );
+			FreeCharMtx( tmpseq1 );
+			FreeCharMtx( tmpseq2 );
+			free( sgap1 );
+			free( egap1 );
+			free( sgap2 );
+			free( egap2 );
+			free( kouho );
+			free( cut1 );
+			free( cut2 );
+			free( tmpptr1 );
+			free( tmpptr2 );
+			free( segment );
+			free( segment1 );
+			free( segment2 );
+			free( sortedseg1 );
+			free( sortedseg2 );
+			if( !kobetsubunkatsu )
+			{
+				FreeFukusosuuMtx ( seqVector1 );
+				FreeFukusosuuMtx ( seqVector2 );
+				FreeFukusosuuVec( naisekiNoWa );
+				FreeFukusosuuMtx( naiseki );
+				FreeDoubleVec( soukan );
+			}
+		}
+		else
+		{
+//			fprintf( stderr, "Did not allocate localarrays in Falign\n" );
+		}
+
+		return( 0.0 );
+	}
 
 	len1 = strlen( seq1[0] );
 	len2 = strlen( seq2[0] );
@@ -750,15 +809,24 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 //				fprintf( stderr, "*totalimpmatch in Falign_localhom = %f\n", *totalimpmatch );
 				break;
 			case( 'A' ):
-				totalscore += partA__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, localhom, &impmatch, cut1[i], cut1[i+1]-1, cut2[i], cut2[i+1]-1, gapmap1, gapmap2, sgap1, sgap2, egap1, egap2 );
+				totalscore += partA__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, localhom, &impmatch, cut1[i], cut1[i+1]-1, cut2[i], cut2[i+1]-1, gapmap1, gapmap2, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres );
 				*totalimpmatch += impmatch;
 //				fprintf( stderr, "*totalimpmatch in Falign_localhom = %f\n", *totalimpmatch );
+
+
 				break;
 			default:
 				fprintf( stderr, "alg = %c\n", alg );
 				ErrorExit( "ERROR IN SOURCE FILE Falign.c" );
 				break;
 		}
+#ifdef enablemultithread
+		if( chudanres && *chudanres )
+		{
+//			fprintf( stderr, "\n\n## CHUUDAN!!! at Falign_localhom\n" );
+			return( -1.0 );
+		}
+#endif
 
 		nlen = strlen( tmpres1[0] );
 		if( totallen + nlen > alloclen )
