@@ -13,7 +13,7 @@ static int treeout;
 static int distout;
 static int noalign;
 static int multidist;
-static int maxdist = 1;
+static int maxdist = 2; // scale -> 2bai
 
 static float lenfaca, lenfacb, lenfacc, lenfacd;
 static int tuplesize;
@@ -1348,7 +1348,7 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'H' )
 			{
@@ -1373,10 +1373,10 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "m" );
-				pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+				pscore = Falign_udpari_long( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 			}
 			else
-				pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+				pscore = Falign( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 		}
 		else
 		{
@@ -1389,10 +1389,10 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 					break;
 				case( 'M' ):
 					fprintf( stderr, "m" );
-					pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'Q' ):
 					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
@@ -1842,8 +1842,8 @@ static void	*addsinglethread( void *arg )
 		free( addmem );
 		free( mseq1 );
 		free( mseq2 );
-		Falign( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
-		A__align( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+		Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
+		A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 		if( commonIP ) FreeIntMtx( commonIP );
 		commonIP = NULL;
 		commonAlloc1 = commonAlloc2 = 0;
@@ -2241,17 +2241,17 @@ static void *distancematrixthread( void *arg )
 			if( j < norg )
 			{
 				if( bunbo == 0.0 )
-					imtx[i][j-i] = 1.0;
+					imtx[i][j-i] = maxdist;
 				else
-					imtx[i][j-i] = ( 1.0 - mtxv / bunbo ) * lenfac;
+					imtx[i][j-i] = maxdist * ( 1.0 - mtxv / bunbo ) * lenfac;
 
 			}
 			else
 			{
 				if( bunbo == 0.0 )
-					nmtx[i][j-norg] = 1.0;
+					nmtx[i][j-norg] = maxdist;
 				else
-					nmtx[i][j-norg] = ( 1.0 - mtxv / bunbo ) * lenfac;
+					nmtx[i][j-norg] = maxdist * ( 1.0 - mtxv / bunbo ) * lenfac;
 			}
 		} 
 		free( table1 );
@@ -2428,16 +2428,16 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 				if( j < norg )
 				{
 					if( bunbo == 0.0 )
-						imtx[i][j-i] = 1.0;
+						imtx[i][j-i] = maxdist;
 					else
-						imtx[i][j-i] = ( 1.0 - mtxv / bunbo ) * lenfac;
+						imtx[i][j-i] = maxdist * ( 1.0 - mtxv / bunbo ) * lenfac;
 				}
 				else
 				{
 					if( bunbo == 0.0 )
-						nmtx[i][j-norg] = 1.0;
+						nmtx[i][j-norg] = maxdist;
 					else
-						nmtx[i][j-norg] = ( 1.0 - mtxv / bunbo ) * lenfac;
+						nmtx[i][j-norg] = maxdist * ( 1.0 - mtxv / bunbo ) * lenfac;
 				}
 			} 
 			free( table1 );
