@@ -22,7 +22,7 @@ static int shishagonyuu( double in )
 	return( out );
 }
 
-static void ambiguousscore( int *amino_n, int n_dis[0x80][0x80] )
+static void ambiguousscore( int *amino_n, int **n_dis )
 {
 	int i;
 	for( i=0; i<26; i++ )
@@ -179,6 +179,12 @@ void constants( int nseq, char **seq )
 		double **pam1 = AllocateDoubleMtx( 4, 4 );
 		double *freq = AllocateDoubleVec( 4 );
 
+		nalphabets = 26;
+		nscoredalphabets = 10;
+
+		n_dis = AllocateIntMtx( nalphabets, nalphabets );
+		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
+
 		scoremtx = -1;
 		if( RNAppenalty == NOTSPECIFIED ) RNAppenalty = DEFAULTRNAGOP_N;
 		if( RNAppenalty_ex == NOTSPECIFIED ) RNAppenalty_ex = DEFAULTRNAGEP_N;
@@ -532,6 +538,8 @@ void constants( int nseq, char **seq )
 
 		fprintf( stderr, "nalphabets = %d\n", nalphabets );
 
+		n_dis = AllocateIntMtx( nalphabets, nalphabets );
+		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
 		n_distmp = AllocateDoubleMtx( nalphabets, nalphabets );
 		datafreq = AllocateDoubleVec( nalphabets );
 		freq = AllocateDoubleVec( nalphabets );
@@ -708,6 +716,11 @@ void constants( int nseq, char **seq )
 //		double tmp;
 		double **n_distmp;
 
+		nalphabets = 26;
+		nscoredalphabets = 20;
+
+		n_dis = AllocateIntMtx( nalphabets, nalphabets );
+		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
 		n_distmp = AllocateDoubleMtx( 20, 20 );
 		datafreq = AllocateDoubleVec( 20 );
 		freq = AllocateDoubleVec( 20 );
@@ -916,6 +929,11 @@ void constants( int nseq, char **seq )
 		double tmp;
 		double delta;
 
+		nalphabets = 26;
+		nscoredalphabets = 20;
+
+		n_dis = AllocateIntMtx( nalphabets, nalphabets );
+		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
 		rsr = AllocateDoubleMtx( 20, 20 );
 		pam1 = AllocateDoubleMtx( 20, 20 );
 		pamx = AllocateDoubleMtx( 20, 20 );
@@ -1201,8 +1219,11 @@ void constants( int nseq, char **seq )
 	for( i=0; i<0x80; i++ )amino_n[i] = -1;
 	for( i=0; i<nalphabets; i++) amino_n[(int)amino[i]] = i;
     for( i=0; i<0x80; i++ ) for( j=0; j<0x80; j++ ) amino_dis[i][j] = 0;
-    for( i=0; i<0x80; i++ ) for( j=0; j<0x80; j++ ) amino_disLN[i][j] = 0;
+    for( i=0; i<nalphabets; i++ ) for( j=0; j<nalphabets; j++ ) n_disLN[i][j] = 0;
     for( i=0; i<0x80; i++ ) for( j=0; j<0x80; j++ ) amino_dis_consweight_multi[i][j] = 0.0;
+
+	n_dis_consweight_multi = AllocateDoubleMtx( nalphabets, nalphabets );
+	n_disFFT = AllocateIntMtx( nalphabets, nalphabets );
     for( i=0; i<nalphabets; i++) for( j=0; j<nalphabets; j++ )
 	{
         amino_dis[(int)amino[i]][(int)amino[j]] = n_dis[i][j];
@@ -1212,19 +1233,26 @@ void constants( int nseq, char **seq )
 
 	if( dorp == 'd' )  /* DNA */
 	{
+#if 0 // ???
 	    for( i=0; i<5; i++) for( j=0; j<5; j++ )
-        	amino_disLN[(int)amino[i]][(int)amino[j]] = n_dis[i][j] + offset - offsetLN;
+        	n_disLN[i][j] = (double)n_dis[i][j] + offset - offsetLN;
 	    for( i=5; i<10; i++) for( j=5; j<10; j++ )
-        	amino_disLN[(int)amino[i]][(int)amino[j]] = n_dis[i][j] + offset - offsetLN;
+        	n_disLN[i][j] = (double)n_dis[i][j] + offset - offsetLN;
 	    for( i=0; i<5; i++) for( j=0; j<5; j++ )
         	n_disFFT[i][j] = n_dis[i][j] + offset - offsetFFT;
 	    for( i=5; i<10; i++) for( j=5; j<10; j++ )
         	n_disFFT[i][j] = n_dis[i][j] + offset - offsetFFT;
+#else
+	    for( i=0; i<10; i++) for( j=0; j<10; j++ )
+        	n_disLN[i][j] = (double)n_dis[i][j] + offset - offsetLN;
+	    for( i=0; i<10; i++) for( j=0; j<10; j++ )
+        	n_disFFT[i][j] = n_dis[i][j] + offset - offsetFFT;
+#endif
 	}
 	else // protein
 	{
 	    for( i=0; i<20; i++) for( j=0; j<20; j++ )
-        	amino_disLN[(int)amino[i]][(int)amino[j]] = n_dis[i][j] + offset - offsetLN;
+        	n_disLN[i][j] = (double)n_dis[i][j] + offset - offsetLN;
 	    for( i=0; i<20; i++) for( j=0; j<20; j++ )
         	n_disFFT[i][j] = n_dis[i][j] + offset - offsetFFT;
 	}
