@@ -16,11 +16,11 @@ int njob, nlenmax;
 int amino_n[0x80];
 char amino_grp[0x80];
 int amino_dis[0x80][0x80];
-int amino_disLN[0x80][0x80];
+double **n_disLN;
 double amino_dis_consweight_multi[0x80][0x80];
-int n_dis[0x80][0x80];
-int n_disFFT[0x80][0x80];
-float n_dis_consweight_multi[0x80][0x80];
+int **n_dis;
+int **n_disFFT;
+double **n_dis_consweight_multi;
 char amino[0x80];
 double polarity[0x80];
 double volume[0x80];
@@ -110,3 +110,7 @@ char TLS *newgapstr = "-";
 
 int nalphabets = 26;
 int nscoredalphabets = 20;
+
+double specificityconsideration = 0.0;
+int ndistclass = 10;
+int maxdistclass = -1;
