@@ -131,6 +131,7 @@ void arguments( int argc, char *argv[] )
 	subalignment = 0;
 	subalignmentoffset = 0;
 	legacygapcost = 0;
+	specificityconsideration = 0.0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -193,6 +194,11 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "nthread = %d\n", nthread );
 					--argc; 
 					goto nextoption;
+				case 's':
+					specificityconsideration = (double)myatof( *++argv );
+//					fprintf( stderr, "specificityconsideration = %f\n", specificityconsideration );
+					--argc; 
+					goto nextoption;
 #if 1
 				case 'a':
 					fmodel = 1;
@@ -240,9 +246,11 @@ void arguments( int argc, char *argv[] )
 				case 'n' :
 					outnumber = 1;
 					break;
+#if 0
 				case 's':
 					treemethod = 's';
 					break;
+#endif
 				case 'X':
 					treemethod = 'X'; // mix
 					break;
@@ -655,6 +663,7 @@ static void *treebasethread( void *arg )
 	float dumfl = 0.0;
 	int ffttry;
 	int m1, m2;
+	double **dynamicmtx;
 #if 0
 	int i, j;
 #endif
@@ -667,6 +676,7 @@ static void *treebasethread( void *arg )
 	effarr2 = AllocateDoubleVec( njob );
 	indication1 = AllocateCharVec( 150 );
 	indication2 = AllocateCharVec( 150 );
+	dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
 
 
 #if 0
@@ -692,10 +702,10 @@ static void *treebasethread( void *arg )
 			pthread_mutex_unlock( targ->mutex );
 			if( commonIP ) FreeIntMtx( commonIP );
 			commonIP = NULL;
-			Falign( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
-			Falign_udpari_long( NULL, NULL, NULL, NULL, 0, 0, 0, NULL );
-			A__align( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
-			G__align11( NULL, NULL, 0, 0, 0 ); // iru?
+			Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
+			Falign_udpari_long( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL );
+			A__align( NULL,  NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			G__align11( NULL, NULL, NULL, 0, 0, 0 ); // iru?
 			free( mseq1 );
 			free( mseq2 );
 			free( localcopy );
@@ -703,6 +713,7 @@ static void *treebasethread( void *arg )
 			free( effarr2 );
 			free( indication1 );
 			free( indication2 );
+			FreeDoubleMtx( dynamicmtx );
 			return( NULL );
 		}
 		*jobpospt = l+1;
@@ -740,6 +751,10 @@ static void *treebasethread( void *arg )
 		m1 = topol[l][0][0];
 		m2 = topol[l][1][0];
 
+//		fprintf( stderr, "\ndistfromtip = %f\n", dep[l].distfromtip );
+//		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip - 0.5 );
+		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip );
+
 		len1 = strlen( aseq[m1] );
 		len2 = strlen( aseq[m2] );
 		if( *alloclen <= len1 + len2 )
@@ -873,11 +888,11 @@ static void *treebasethread( void *arg )
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "m" );
-				pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+				pscore = Falign_udpari_long( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 			}
 			else
 			{
-				pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+				pscore = Falign( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 			}
 		}
 		else
@@ -892,13 +907,13 @@ static void *treebasethread( void *arg )
 				case( 'M' ):
 					fprintf( stderr, "m" );
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'Q' ):
 					if( clus1 == 1 && clus2 == 1 && 0 )
 					{
 //							fprintf( stderr, "%d-%d", clus1, clus2 );
-							pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
+							pscore = G__align11( dynamicmtx, mseq1, mseq2, *alloclen, outgap, outgap );
 					}
 					else
 					{
@@ -915,12 +930,12 @@ static void *treebasethread( void *arg )
 					if( clus1 == 1 && clus2 == 1 )
 					{
 //						fprintf( stderr, "%d-%d", clus1, clus2 );
-						pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
+						pscore = G__align11( dynamicmtx, mseq1, mseq2, *alloclen, outgap, outgap );
 					}
 					else
 					{
 //						fprintf( stderr, "%d-%d", clus1, clus2 );
-						pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					}
 					break;
 				default:
@@ -975,7 +990,7 @@ static void *treebasethread( void *arg )
 }
 #endif
 
-static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, double *effarr, int *alloclen )
+static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, Treedep *dep, double *effarr, int *alloclen )
 {
 	int l, len1, len2, i, m;
 	int len1nocommongap, len2nocommongap;
@@ -991,6 +1006,7 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 	static int *gaplen;
 	static int *gapmap;
 	static int *alreadyaligned;
+	static double **dynamicmtx;
 #if 0
 	int i, j;
 #endif
@@ -1005,6 +1021,7 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 		gaplen = AllocateIntVec( *alloclen+10 );
 		gapmap = AllocateIntVec( *alloclen+10 );
 		alreadyaligned = AllocateIntVec( njob );
+		dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
 	}
 	for( i=0; i<njob-nadd; i++ ) alreadyaligned[i] = 1;
 	for( i=njob-nadd; i<njob; i++ ) alreadyaligned[i] = 0;
@@ -1028,6 +1045,10 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 	tscore = 0.0;
 	for( l=0; l<njob-1; l++ )
 	{
+
+//		fprintf( stderr, "\ndistfromtip = %f\n", dep[l].distfromtip );
+		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip );
+//		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, ( dep[l].distfromtip - 0.2 ) * 3 );
 		if( mergeoralign[l] == 'n' )
 		{
 //			fprintf( stderr, "SKIP!\n" );
@@ -1187,11 +1208,11 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "m" );
-				pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+				pscore = Falign_udpari_long( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 			}
 			else
 			{
-				pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+				pscore = Falign( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 //				fprintf( stderr, "######### mseq1[0] = %s\n", mseq1[0] );
 			}
 		}
@@ -1207,13 +1228,13 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 				case( 'M' ):
 					fprintf( stderr, "m" );
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'Q' ):
 					if( clus1 == 1 && clus2 == 1 && 0 )
 					{
 //							fprintf( stderr, "%d-%d", clus1, clus2 );
-							pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
+							pscore = G__align11( dynamicmtx, mseq1, mseq2, *alloclen, outgap, outgap );
 					}
 					else
 					{
@@ -1230,12 +1251,12 @@ static void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 					if( clus1 == 1 && clus2 == 1 )
 					{
 //						fprintf( stderr, "%d-%d", clus1, clus2 );
-						pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
+						pscore = G__align11( dynamicmtx, mseq1, mseq2, *alloclen, outgap, outgap );
 					}
 					else
 					{
 //						fprintf( stderr, "%d-%d", clus1, clus2 );
-						pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					}
 					break;
 				default:
@@ -1649,9 +1670,9 @@ int main( int argc, char *argv[] )
 //				fprintf( stderr, "lenfac = %f (%.0f,%.0f)\n", lenfac, longer, shorter );
 				bunbo = MIN( mtx[i][0], mtx[j][0] );
 				if( bunbo == 0.0 )
-					mtx[i][j-i] = 1.0;
+					mtx[i][j-i] = 2.0; // 2013/Oct/17 -> 2bai
 				else
-					mtx[i][j-i] = ( 1.0 - mtx[i][j-i] / bunbo ) * lenfac;
+					mtx[i][j-i] = ( 1.0 - mtx[i][j-i] / bunbo ) * lenfac * 2.0; // 2013/Oct/17 -> 2bai
 //				fprintf( stdout, "##### mtx = %f, mtx[i][0]=%f, mtx[j][0]=%f, bunbo=%f\n", mtx[i][j-i], mtx[i][0], mtx[j][0], bunbo );
 			}
 		}
@@ -2084,7 +2105,7 @@ int main( int argc, char *argv[] )
 	else
 #endif
 	{
-		treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, eff, &alloclen );
+		treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, dep, eff, &alloclen );
 	}
 	fprintf( stderr, "\ndone.\n\n" );
 #if DEBUG
