@@ -375,7 +375,7 @@ static void	*directionthread( void *arg )
 //			strcpy( mseq2[0], seq[j] );
 			mseq1[0] = tmpseq;
 			mseq2[0] = seq[j];
-//			res[j] = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1, mseq2, 0 );
+//			res[j] = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, 0 );
 			res[j] = L__align11_noalign( mseq1, mseq2 );
 		}
 		else
@@ -512,8 +512,8 @@ int main( int argc, char *argv[] )
 		{
 			gappick0( mseq2[0], seq[i] );
 
-//			res_forward = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1f, mseq2, 0 );
-//			res_reverse = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1r, mseq2, 0 );
+//			res_forward = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1f, mseq2, 0 );
+//			res_reverse = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1r, mseq2, 0 );
 
 			res_forward = L__align11_noalign( mseq1f, mseq2 );
 			res_reverse = L__align11_noalign( mseq1r, mseq2 );
@@ -521,13 +521,13 @@ int main( int argc, char *argv[] )
 
 			strcpy( mseq2[0], seq[i] );
 			strcpy( mseq1f[0], seq[0] );
-			res_forward = G__align11( mseq1f, mseq2, nlenmax*2, 0, 0 );
+			res_forward = G__align11( n_dis_consweight_multi, mseq1f, mseq2, nlenmax*2, 0, 0 );
 			fprintf( stdout, "%s\n", mseq1f[0] );
 			fprintf( stdout, "%s\n", mseq2[0] );
 
 			strcpy( mseq2[0], seq[i] );
 			sreverse( mseq1r[0], seq[0] );
-			res_reverse = G__align11( mseq1r, mseq2, nlenmax*2, 0, 0 );
+			res_reverse = G__align11( n_dis_consweight_multi, mseq1r, mseq2, nlenmax*2, 0, 0 );
 			fprintf( stdout, "%s\n", mseq1r[0] );
 			fprintf( stdout, "%s\n", mseq2[0] );
 #endif
