@@ -20,7 +20,7 @@
 #include <pthread.h>
 #endif
 
-#define VERSION "7.123b"
+#define VERSION "7.127b"
 #define SHOWVERSION fprintf( stderr, "%s (%s) Version " VERSION " alg=%c, model=%s\n%d thread(s)\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, nthread )
 
 #define FFT_THRESHOLD  80
@@ -56,11 +56,11 @@ extern int njob, nlenmax;
 extern int amino_n[0x80];
 extern char amino_grp[0x80];
 extern int amino_dis[0x80][0x80];
-extern int amino_disLN[0x80][0x80];
+extern double **n_disLN;
 extern double amino_dis_consweight_multi[0x80][0x80];
-extern int n_dis[0x80][0x80];
-extern int n_disFFT[0x80][0x80];
-extern float n_dis_consweight_multi[0x80][0x80];
+extern int **n_dis;
+extern int **n_disFFT;
+extern double **n_dis_consweight_multi;
 extern char amino[0x80];
 extern double polarity[0x80];
 extern double volume[0x80];
@@ -314,3 +314,5 @@ extern TLS char *newgapstr;
 
 extern int nalphabets;
 extern int nscoredalphabets;
+extern double specificityconsideration;
+extern int ndistclass, maxdistclass;
