@@ -258,7 +258,7 @@ static float recallpairfoldalign( char **mseq1, char **mseq2, int m1, int m2, in
 	if( strstr( foldalignopt, "-global") )
 	{
 		fprintf( stderr, "Calling G__align11\n" );
-		value = G__align11( mseq1, mseq2, alloclen, outgap, outgap );
+		value = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
 		*of1pt = 0;
 		*of2pt = 0;
 	}
@@ -1965,8 +1965,8 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 				commonIP = NULL;
 				if( commonJP ) FreeIntMtx( commonJP );
 				commonJP = NULL;
-				Falign( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
-				G__align11( NULL, NULL, 0, 0, 0 ); // 20130603
+				Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
+				G__align11( NULL, NULL, NULL, 0, 0, 0 ); // 20130603
 				G__align11_noalign( NULL, 0, 0, NULL, NULL, 0 );
 				L__align11( NULL, NULL, 0, NULL, NULL );
 				L__align11_noalign( NULL, NULL );
@@ -2044,7 +2044,7 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 
 		if( use_fft )
 		{
-			pscore = Falign( mseq1, mseq2, effarr1, effarr2, 1, 1, alloclen, &intdum, NULL, 0, NULL );
+			pscore = Falign( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, 1, 1, alloclen, &intdum, NULL, 0, NULL );
 //			fprintf( stderr, "pscore (fft) = %f\n", pscore );
 			off1 = off2 = 0;
 		}
@@ -2077,7 +2077,7 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 						else
 							pscore = L__align11_noalign( distseq1, distseq2 );
 					}
-//					pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
+//					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
 					break;
 				case( 'Y' ):
 					if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) ) // new sequence vs exiting sequence nomi keisan
@@ -2096,15 +2096,15 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 				case( 'A' ):
 					if( store_localhom )
 					{
-						pscore = G__align11( mseq1, mseq2, alloclen, outgap, outgap );
-						if( thereisx ) pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+						pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+						if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
 					}
 					else
-						pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+						pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
 					off1 = off2 = 0;
 					break;
 				case( 'N' ):
-//					pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1, mseq2, alloclen );
+//					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
 					pscore = genL__align11( mseq1, mseq2, alloclen, &off1, &off2 );
 					if( thereisx )
 					{
@@ -2115,8 +2115,8 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 					break;
 				case( 't' ):
 					off1 = off2 = 0;
-//					pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1, mseq2, alloclen );
-					pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // tsuneni distseq shiyou
+//					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
+					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // tsuneni distseq shiyou
 					break;
 				case( 's' ):
 					pscore = callmxscarna_giving_bpp( mseq1, mseq2, bpp[i], bpp[j], alloclen, i, j );
@@ -2132,7 +2132,7 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 					off1 = off2 = 0;
 					break;
 				case( 'K' ):
-					pscore = genG__align11( mseq1, mseq2, alloclen );
+					pscore = genG__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen );
 					off1 = off2 = 0;
 					break;
 				case( 'H' ):
@@ -2481,7 +2481,7 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 	
 				if( use_fft )
 				{
-					pscore = Falign( mseq1, mseq2, effarr1, effarr2, 1, 1, alloclen, &intdum, NULL, 0, NULL );
+					pscore = Falign( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, 1, 1, alloclen, &intdum, NULL, 0, NULL );
 //					fprintf( stderr, "pscore (fft) = %f\n", pscore );
 					off1 = off2 = 0;
 				}
@@ -2490,22 +2490,22 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 					switch( alg )
 					{
 						case( 't' ):
-//							pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1, mseq2, alloclen );
-							pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // tsuneni distseq shiyou
+//							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
+							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // tsuneni distseq shiyou
 							off1 = off2 = 0;
 							break;
 						case( 'A' ):
 							if( store_localhom )
 							{
-								pscore = G__align11( mseq1, mseq2, alloclen, outgap, outgap );
-								if( thereisx ) pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+								pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+								if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
 							}
 							else
-								pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+								pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
 							off1 = off2 = 0;
 							break;
 						case( 'N' ):
-//							pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, mseq1, mseq2, alloclen );
+//							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
 							pscore = genL__align11( mseq1, mseq2, alloclen, &off1, &off2 );
 							if( thereisx )
 							{
@@ -2539,7 +2539,7 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 								else
 									pscore = L__align11_noalign( distseq1, distseq2 ); // all pair
 							}
-//							pscore = G__align11_noalign( amino_dis, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
+//							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
 							break;
 						case( 'Y' ):
 							if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) ) // new sequence vs exiting sequence nomi keisan
