@@ -118,6 +118,7 @@ void arguments( int argc, char *argv[] )
 	subalignment = 0;
 	subalignmentoffset = 0;
 	legacygapcost = 0;
+	specificityconsideration = 0.0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -207,12 +208,13 @@ void arguments( int argc, char *argv[] )
 					subalignmentoffset = myatoi( *++argv );
 					--argc;
 					goto nextoption;
+				case 's':
+					specificityconsideration = (double)myatof( *++argv );
+//					fprintf( stderr, "specificityconsideration = %f\n", specificityconsideration );
+					--argc; 
+					goto nextoption;
 				case 'R':
 					rnaprediction = 'r';
-					break;
-				case 's':
-					RNAscoremtx = 'r';
-					break;
 #if 1
 				case 'a':
 					fmodel = 1;
@@ -456,9 +458,9 @@ static void *distancematrixthread( void *arg )
 		ssj = selfscore[j];
 		bunbo = MIN( ssi, ssj );
 		if( bunbo == 0.0 )
-			iscore[i][j-i] = 1.0;
+			iscore[i][j-i] = 2.0; // 2013/Oct/17
 		else
-			iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo;
+			iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo ) * 2.0; // 2013/Oct/17
 	}
 }
 
@@ -497,11 +499,13 @@ static void *treebasethread( void *arg )
 	float dumfl = 0.0;
 	int ffttry;
 	RNApair ***grouprna1 = NULL, ***grouprna2 = NULL;
+	double **dynamicmtx;
 
 
 	mseq1 = AllocateCharMtx( njob, 0 );
 	mseq2 = AllocateCharMtx( njob, 0 );
 	localcopy = calloc( njob, sizeof( char * ) );
+	dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -560,9 +564,9 @@ static void *treebasethread( void *arg )
 			pthread_mutex_unlock( targ->mutex );
 			if( commonIP ) FreeIntMtx( commonIP );
 			commonIP = NULL;
-			Falign( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
-			Falign_udpari_long( NULL, NULL, NULL, NULL, 0, 0, 0, NULL );
-			A__align( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
+			Falign_udpari_long( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL );
+			A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			free( mseq1 );
 			free( mseq2 );
 			free( localcopy );
@@ -572,6 +576,7 @@ static void *treebasethread( void *arg )
 			free( effarr2_kozo );
 			free( indication1 );
 			free( indication2 );
+			FreeDoubleMtx( dynamicmtx );
 			if( rnakozo && rnaprediction == 'm' )
 			{
 				if( grouprna1 ) free( grouprna1 ); // nakami ha?
@@ -629,6 +634,10 @@ static void *treebasethread( void *arg )
 		m1 = topol[l][0][0];
 		m2 = topol[l][1][0];
 
+//		fprintf( stderr, "\ndistfromtip = %f\n", dep[l].distfromtip );
+//		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip - 0.5 );
+		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip );
+
 //		pthread_mutex_lock( targ->mutex );
 
 
@@ -753,7 +762,7 @@ static void *treebasethread( void *arg )
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'H' )
 			{
@@ -778,10 +787,10 @@ static void *treebasethread( void *arg )
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "m" );
-				pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+				pscore = Falign_udpari_long( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 			}
 			else
-				pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+				pscore = Falign( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 		}
 		else
 		{
@@ -794,10 +803,10 @@ static void *treebasethread( void *arg )
 					break;
 				case( 'M' ):
 					fprintf( stderr, "m" );
-					pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'Q' ):
 					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
@@ -858,7 +867,7 @@ static void *treebasethread( void *arg )
 }
 #endif
 
-void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, double *effarr, int *alloclen, LocalHom **localhomtable, RNApair ***singlerna, double *effarr_kozo )
+void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, Treedep *dep, double *effarr, int *alloclen, LocalHom **localhomtable, RNApair ***singlerna, double *effarr_kozo )
 {
 	int i, l, m;
 	int len1nocommongap, len2nocommongap;
@@ -879,6 +888,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	float dumfl = 0.0;
 	int ffttry;
 	RNApair ***grouprna1 = NULL, ***grouprna2 = NULL;
+	double **dynamicmtx;
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -900,6 +910,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 		gaplen = AllocateIntVec( *alloclen+10 );
 		gapmap = AllocateIntVec( *alloclen+10 );
 		alreadyaligned = AllocateIntVec( njob );
+		dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
 #if 0
 #else
 		if( constraint )
@@ -940,6 +951,9 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	tscore = 0.0;
 	for( l=0; l<njob-1; l++ )
 	{
+//		fprintf( stderr, "\ndistfromtip = %f\n", dep[l].distfromtip );
+		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, dep[l].distfromtip );
+//		makedynamicmtx( dynamicmtx, n_dis_consweight_multi, ( dep[l].distfromtip - 0.2 ) * 3 );
 		if( mergeoralign[l] == 'n' )
 		{
 //			fprintf( stderr, "SKIP!\n" );
@@ -1088,7 +1102,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'H' )
 			{
@@ -1113,10 +1127,10 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "m" );
-				pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+				pscore = Falign_udpari_long( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 			}
 			else
-				pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+				pscore = Falign( NULL, NULL, dynamicmtx, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 		}
 		else
 		{
@@ -1129,10 +1143,10 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 					break;
 				case( 'M' ):
 					fprintf( stderr, "m" );
-					pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'Q' ):
 					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
@@ -1550,10 +1564,10 @@ int main( int argc, char *argv[] )
 						ssj = selfscore[j];
 						bunbo = MIN( ssi, ssj );
 						if( bunbo == 0.0 )
-							iscore[i][j-i] = 1.0;
+							iscore[i][j-i] = 2.0; // 2013/Oct/17 2bai
 						else
 //							iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / MIN( selfscore[i], selfscore[j] );
-							iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo;
+							iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo ) * 2.0; // 2013/Oct/17 2bai
 		
 #if 0
 						fprintf( stderr, "### ssj = %f\n", ssj );
@@ -2083,7 +2097,7 @@ int main( int argc, char *argv[] )
 	else
 #endif
 
-		treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, eff, &alloclen, localhomtable, singlerna, eff_kozo_mapped );
+		treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, dep, eff, &alloclen, localhomtable, singlerna, eff_kozo_mapped );
 	fprintf( stderr, "\ndone.\n" );
 	if( scoreout )
 	{
